// radioactive-0.5/driver.cc

// RadioActive Copyright (C) 1999 RDI Gerg <cactus@cactus.rulez.org>
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License version 2
// (included in the RadioActive distribution in doc/GPL) as published by
// the Free Software Foundation.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

//$Id: driver.cc,v 1.10 1999/06/02 15:20:14 cactus Exp $
#include "driver.h"

#include <fcntl.h>
#include <sys/ioctl.h>
#include <math.h>
#include <linux/videodev.h>

Radio::Radio(const string& devicefile = DEVFILE):
    vol(RADIO_VOL_DEF)
{
    if (!((fd = open(devicefile.c_str(), O_RDONLY)) > 0))
    {
	fprintf(stderr, _("Couldn't open radio device %s"),
		devicefile.c_str());
	fprintf(stderr, "\n");
	exit (1);
    }
}

void Radio::set_vol(int lvl)
{
    
    struct video_audio va;
    if (lvl > RADIO_VOL_MAX)
        lvl = RADIO_VOL_MAX;
    if (lvl < RADIO_VOL_MIN)
        lvl = RADIO_VOL_MIN;

    va.flags = VIDEO_AUDIO_VOLUME|(muted ? VIDEO_AUDIO_MUTE
				   : 0);
//    va.flags = VIDEO_AUDIO_VOLUME;
    va.audio = 0;
    va.volume = lvl * (65535/(RADIO_VOL_MAX-RADIO_VOL_MIN));
    ioctl (fd, VIDIOCSAUDIO, &va);
    vol = lvl;
}

void Radio::mute(bool mute)
{
    struct video_audio va;
    if (mute)
	va.flags = VIDEO_AUDIO_MUTE;
    else {
	va.volume = vol * (65535/(RADIO_VOL_MAX - RADIO_VOL_MIN));
	va.flags = VIDEO_AUDIO_VOLUME;
    }
    va.audio = 0;
    ioctl (fd, VIDIOCSAUDIO, &va);
    muted = mute;
}

void Radio::toggle_mute()
{
    mute(!muted);
}

void Radio::set(double freq)
{
    fq = freq;

    struct video_tuner v;
    unsigned long xl_freq;
    freq *= 1000;
    
    xl_freq = (unsigned long)(freq * get_freq_fact () + 0.5);
    
    v.tuner = 0;
    ioctl (fd, VIDIOCSFREQ, &xl_freq);
    ioctl (fd, VIDIOCGTUNER, &v);
}

double Radio::get_freq_fact()
{
    struct video_tuner tuner;
    tuner.tuner = 0;
    if (ioctl (fd, VIDIOCGTUNER, &tuner) < 0)
        return .016;
    if ((tuner.flags & VIDEO_TUNER_LOW) == 0)
        return .016;
    return 16;
}
