// radioactive-0.5/radioactive.cc

// RadioActive Copyright (C) 1999 RDI Gerg <cactus@cactus.rulez.org>
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License version 2
// (included in the RadioActive distribution in doc/GPL) as published by
// the Free Software Foundation.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

//$Id: radioactive.cc,v 1.14 1999/06/10 14:46:50 cactus Exp $ -*- c++ -*-
#include "radioactive.h"

#include "file.h"
#include "driver.h"
#include <getopt.h>

#include "wndMain.h"

namespace arg
{
    string devfile = DEVFILE;
    double freq = 0;
    bool console = false;
    bool mute = false;
}

void usage(const string& myname)
{
    cerr << _("Usage:") << " " << myname << " [-f " << _("freq")
	 << "|-m|-v] [-d " << _("devicefile") << "] [-c]" << endl << endl;
    cerr << "-f\t" << _("Specify the initial frequency") << endl
	 << "-d\t" << _("Radio device (default is ") << DEVFILE << ")" << endl
	 << "-c\t" << _("Use command line-only interface (default if not under X)")
	 << endl
	 << "-m\t" << _("Just mute radio and exit") << endl
	 << "-v\t" << _("Print version informaion and exit") << endl
	 << endl;
}

void parse(int argc, char **argv)
{
    int c;
    while ((c = getopt (argc, argv, "vf:d:cmh")) != -1)
	switch (c)
	{
	case 'v':
	    cout << PROGNAME << " " << VERSION
		 << " (C) 1999 ERDI Gergo <cactus@cactus.rulez.org>" << endl;
	    exit(0);
	case 'f':
	    arg::freq = atof(optarg);
	    break;
	case 'd':
	    arg::devfile = optarg;
	    break;
	case 'c':
	    arg::console = true;
	    break;
	case 'm':
	    arg::mute = true;
	    break;
	case 'h':
	    usage(argv[0]);
	    exit(0);
	case '?':
	    usage(argv[0]);
	    exit(1);
	}
}

int stop(GdkEventAny* e)
{
    Gnome_Main::instance()->quit();
    return 0;
}

int main(int argc, char** argv)
{
    setlocale(LC_MESSAGES,"");
    bindtextdomain(PACKAGE, LOCALE_DIR);
    textdomain(PACKAGE);

    char **arg_dummy = new char*[1];
    arg_dummy[0] = argv[0];
    arg_dummy[1] = NULL;
    
    parse(argc, argv);
    Radio radio(arg::devfile);
    Gnome_Main* m = NULL;

    // Muting
    if (arg::mute)
    {
	radio.mute(true);
	exit(0);
    }

    // Load previous values
    if (arg::freq)
	radio.set(arg::freq);
    else
	radio.set(load_value<float>("last"));
    radio.set_vol(load_value<int>("volume"));
    radio.mute(false);

    // User interface
    if (getenv("DISPLAY") && !arg::console)
    {
	m = new Gnome_Main(PROGNAME, VERSION, 1, arg_dummy);
	wndMain w(radio);
	connect_to_function(w.delete_event, &stop);
	
	w.set_speedtuner(
	    load_button_values(((RADIO_PROGBUTTON_COL) * (RADIO_PROGBUTTON_ROW))));
	
	w.show();
	m->run();

	save_button_values(w.get_speedtuner());
    }
    
    // Save current values
    save_value("last", radio.get());
    save_value("volume", radio.get_vol());

    if (m) delete m;
    delete[] arg_dummy;
    return 0;
}
