// radioactive-0.5/wndMain.cc

// RadioActive Copyright (C) 1999 RDI Gerg <cactus@cactus.rulez.org>
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License version 2
// (included in the RadioActive distribution in doc/GPL) as published by
// the Free Software Foundation.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

// $Id: wndMain.cc,v 1.27 1999/06/10 21:11:44 cactus Exp $
#include "wndMain.h"

#include "radioactive.h"
#include <strstream>

wndMain::wndMain(Radio& radiodev):
    Gtk_Window(GTK_WINDOW_TOPLEVEL),
    radio(radiodev),
    tuner(RADIO_FREQ_MIN, RADIO_FREQ_MAX),
    buttons(RADIO_PROGBUTTON_ROW, RADIO_PROGBUTTON_COL),
    volume(),

    tune_table(3, 3),
    fine_up(">"), fine_down("<"),
    up(">>"), down("<<"),
    fine("FINE"), normal("NORMAL"),
    
    box(false, 5)
{
    set_title(PROGNAME " " VERSION);
    set_border_width(5);
    set_policy(false, false, false);

    tuner.set_value(curr_val = radio.get());
    connect_to_method(tuner.tune, this, &tuner_changed);
    build_table();
    
    box.add(tune_table);

    connect_to_signal(buttons.clicked, tuner.set_value);
    connect_to_method(buttons.rclicked, this, &speed_change);

    box.pack_start(buttons, false, false);

    volume.set(radio.get_vol());
    connect_to_method(volume.mute, &radio, &radio.mute);
    connect_to_signal(volume.mute, btnMute_clicked);
    connect_to_method(volume.change, &radio, &radio.set_vol);
    
    box.pack_start(volume, false, false);
    box.show_all();
    add(box);
}

void wndMain::tuner_fine_tune(float delta)
{
    tuner.set_value(curr_val + delta);
}

void wndMain::build_table()
{
#define SET_TUNEVAL(w, d) connect_to_method((w).clicked, this, &tuner_fine_tune, (float)(d));
#define TUNER_ATTACH(w, x, y) tune_table.attach((w), (x), ((x) + 1),\
						(y), ((y) + 1),\
						(GTK_FILL | GTK_EXPAND),\
						(GTK_FILL | GTK_EXPAND), 2, 2);

    tune_table.set_usize(200, 0);
    tune_table.set_border_width(2);

    tune_table.attach(tuner, 0, 3, 0, 1);
    
    SET_TUNEVAL(fine_up, +0.05);
    SET_TUNEVAL(fine_down, -0.05);
    SET_TUNEVAL(up, +0.5);
    SET_TUNEVAL(down, -0.5);

    TUNER_ATTACH(fine, 0, 1);
    TUNER_ATTACH(fine_down, 1, 1);
    TUNER_ATTACH(fine_up, 2, 1);
    TUNER_ATTACH(normal, 0, 2);
    TUNER_ATTACH(down, 1, 2);
    TUNER_ATTACH(up, 2, 2);

#undef TUNER_ATTACH
#undef SET_TUNEVAL
}

void wndMain::set()
{
    volume.set(radio.get_vol());
    tuner.set_value(curr_val = radio.get());
    volume.set_mute(radio.get_mute());
}

void wndMain::tuner_changed(float val)
{
    radio.set(curr_val = val);
}

void wndMain::speed_change(int btn)
{
    buttons.set(btn, curr_val);
}

Gnome_About* wndMain::about()
{
    string info = _("Radio tuner for Video4Linux-compatible devices");
    info += "\n";
    info += _("Visit http://cactus.rulez.org/radioactive/ for more information");
    
    const char *authors[2] = {"RDI Gerg <cactus@cactus.rulez.org>", NULL};
    
    GtkWidget* wnd = gnome_about_new(PROGNAME, VERSION,
				     "(C) 1999 "
				     "RDI Gerg",
				     authors, info.c_str(), NULL);
    return new Gnome_About(GNOME_ABOUT(wnd));
}

void wndMain::show_about()
{
    Gnome_About *wnd = about();
//    wnd->set_modal(true);
    wnd->show_all();
}

int wndMain::delete_event_impl(GdkEventAny* e)
{
    hide();
    return 1;
}
